@@ -1,5 +1,5 @@
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: payments.c,v 1.16 2004/02/18 12:49:22 lukasz Exp $
+ *  $Id: payments.c,v 1.20 2004/04/03 20:09:05 alec Exp $
  */
 #include <stdio.h>
 #include <syslog.h>
@@ -180,7 +180,7 @@ void reload(GLOBAL *g, struct payments_module *p)
 		g->db_free(res);
 
 		// payments accounting and invoices writing
-		if( (res = g->db_pquery("SELECT assignments.id AS id, tariffid, userid, period, at, value, taxvalue, pkwiu, uprate, downrate, tariffs.name AS tariff, invoice, UPPER(lastname) AS lastname, users.name AS name, address, zip, city, nip, pesel, phone1 AS phone FROM assignments, tariffs, users WHERE tariffs.id = tariffid AND userid = users.id AND status = 3 AND deleted = 0 AND value <> 0 AND ((period = 0 AND at = ?) OR (period = 1 AND at = ?) OR (period = 2 AND at = ?) OR (period = 3 AND at = ?)) ORDER BY userid, value DESC", weekday, monthday, quarterday, yearday))!= NULL ) {
+		if( (res = g->db_pquery("SELECT assignments.id AS id, tariffid, userid, period, at, value, taxvalue, pkwiu, uprate, downrate, tariffs.name AS tariff, invoice, UPPER(lastname) AS lastname, users.name AS name, address, zip, city, nip, pesel, phone1 AS phone FROM assignments, tariffs, users WHERE tariffs.id = tariffid AND userid = users.id AND status = 3 AND deleted = 0 AND value <> 0 AND ((period = 0 AND at = ?) OR (period = 1 AND at = ?) OR (period = 2 AND at = ?) OR (period = 3 AND at = ?)) AND (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) ORDER BY userid, value DESC", weekday, monthday, quarterday, yearday))!= NULL ) {
 	
 			for(i=0; i<res->nrows; i++) {
 			
@@ -203,7 +203,7 @@ void reload(GLOBAL *g, struct payments_module *p)
 				
 					if( last_userid != atoi(g->db_get_data(res,i,"userid")) ) {
 						// prepare insert to 'invoices' table
-						insert_inv = strdup("INSERT INTO invoices (number, customerid, name, address, zip, city, phone, nip, pesel, cdate, paytime, paytype, finished) VALUES (%number, %customerid, '%lastname %name', '%address', '%zip', '%city', '%phone', '%nip', '%pesel', %NOW%, 14, 'PRZELEW', 1 )");
+						insert_inv = strdup("INSERT INTO invoices (number, customerid, name, address, zip, city, phone, nip, pesel, cdate, paytime, paytype, finished) VALUES (%number, %customerid, '%lastname %name', '%address', '%zip', '%city', '%phone', '%nip', '%pesel', %NOW%, %deadline, '%paytype', 1 )");
 						g->str_replace(&insert_inv, "%number", itoa(++number));
 						g->str_replace(&insert_inv, "%customerid", g->db_get_data(res,i,"userid"));				
 						g->str_replace(&insert_inv, "%lastname", g->db_get_data(res,i,"lastname"));
@@ -214,7 +214,9 @@ void reload(GLOBAL *g, struct payments_module *p)
 						g->str_replace(&insert_inv, "%phone", g->db_get_data(res,i,"phone"));
 						g->str_replace(&insert_inv, "%nip", g->db_get_data(res,i,"nip"));
 						g->str_replace(&insert_inv, "%pesel", g->db_get_data(res,i,"pesel"));
-	
+						g->str_replace(&insert_inv, "%deadline", p->deadline);
+						g->str_replace(&insert_inv, "%paytype", p->paytype);
+			
 						g->db_exec(insert_inv);			
 						free(insert_inv);
 						
@@ -279,9 +281,14 @@ void reload(GLOBAL *g, struct payments_module *p)
 		g->db_exec("INSERT INTO timestamps (tablename, time) VALUES ('cash', %NOW%)");
 		g->db_exec("INSERT INTO timestamps (tablename, time) VALUES ('_global', %NOW%)");
 	}
+	// remove old assignments
+	if(p->expiry_days<0) p->expiry_days *= -1; // number of expiry days can't be negative
+	g->db_pexec("DELETE FROM assignments WHERE dateto < %NOW% - 86400 * ? AND dateto != 0 ", itoa(p->expiry_days));
 
 	// clean up
 	free(p->comment);
+	free(p->deadline);
+	free(p->paytype);
 }
 
 struct payments_module * init(GLOBAL *g, MODULE *m)
@@ -304,8 +311,14 @@ struct payments_module * init(GLOBAL *g, MODULE *m)
 
 	s = g->str_concat(instance, ":comment");
 	p->comment = strdup(g->iniparser_getstring(ini, s, "Abonament wg taryfy: %tariff za okres: %period"));
+	free(s); s = g->str_concat(instance, ":deadline");
+	p->deadline = strdup(g->iniparser_getstring(ini, s, "14"));
+	free(s); s = g->str_concat(instance, ":paytype");
+	p->paytype = strdup(g->iniparser_getstring(ini, s, "PRZELEW"));
 	free(s); s = g->str_concat(instance, ":up_payments");
 	p->up_payments = g->iniparser_getboolean(ini, s, 1);
+	free(s); s = g->str_concat(instance, ":expiry_days");
+	p->expiry_days = g->iniparser_getint(ini, s, 30);
 	
 	g->iniparser_freedict(ini);
 	free(s);
