@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.19 2003/10/08 04:39:38 lukasz Exp $
+ *  $Id: LMSDB_common.class.php,v 1.26 2004/03/14 21:41:32 lukasz Exp $
  */
 
 /*
@@ -30,39 +30,37 @@
 
 Class LMSDB_common
 {
-	var $_version="1.1.5 Amaonet";
-	var $_revision='$Revision: 1.19 $';
+	var $_version = '1.3-cvs';
+	var $_revision = '$Revision: 1.26 $';
 	
 	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
 	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
 	// zaadowa
 	
-	var $_loaded=FALSE;
+	var $_loaded = FALSE;
 
 	// Wewntrzne zmienne bazy danych, tj, resource, link, itp.
 
-	var $_dbtype='NONE';
-	var $_dblink=NULL;
-	var $_dbhost=NULL;
-	var $_dbuser=NULL;
-	var $_dbname=NULL;
-	var $_error=NULL;
-	var $_query=NULL;
-	var $_result=NULL;
+	var $_dbtype = 'NONE';
+	var $_dblink = NULL;
+	var $_dbhost = NULL;
+	var $_dbuser = NULL;
+	var $_dbname = NULL;
+	var $_error = FALSE;
+	var $_query = NULL;
+	var $_result = NULL;
+
+	var $errors = array();
 
 	function LMSDB_common()
 	{
 		// zabezpieczmy si przed inicjowaniem tej klasy samej w sobie
-		
 		die();
-
 	}
 	
 	function Connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-
 		// Inicjuje poczenie do bazy danych
-	
 		return $this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
@@ -73,16 +71,19 @@ Class LMSDB_common
 
 	function Execute($query, $inputarray = NULL)
 	{
-		// wykonuje query sql'owe, jednoczenie je parsujc
- // 		echo $this->_query_parser($query,$inputarray)."<BR>";
-		$this->_driver_execute($this->_query_parser($query,$inputarray));
-		// i zwraca ilo zmodyfikowanych wierszy
+	//	echo $this->_query_parser($query,$inputarray).'<HR>';
+		if(! $this->_driver_execute($this->_query_parser($query,$inputarray)))
+		{
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => $this->_driver_geterror()
+					);
+		}
 		return $this->_driver_affected_rows();
 	}
 
 	function GetAll($query = NULL, $inputarray = NULL)
 	{
-
 		// zwraca tablic z caym wynikiem
 	
 		if($query)
@@ -167,6 +168,11 @@ Class LMSDB_common
 		return $this->_driver_committrans();
 	}
 
+	function GetDBVersion()
+	{
+		return $this->_driver_dbversion();
+	}
+
 	function _query_parser($query, $inputarray = NULL)
 	{
 		// najpierw sparsujmy wszystkie specjalne meta mieci.
@@ -217,47 +223,4 @@ Class LMSDB_common
 
 }
 
-/* 
- * $Log: LMSDB_common.class.php,v $
- * Revision 1.19  2003/10/08 04:39:38  lukasz
- * - temporary save
- *
- * Revision 1.18  2003/10/06 05:33:04  lukasz
- * - temporary save / lot of fixes
- *
- * Revision 1.17  2003/09/12 22:22:52  alec
- * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
- *
- * Revision 1.16  2003/09/10 00:16:19  lukasz
- * - LMSDB::Destroy();
- *
- * Revision 1.15  2003/08/28 21:07:21  lukasz
- * - added support for transactions
- *
- * Revision 1.14  2003/08/27 19:25:18  lukasz
- * - unset result before returning it
- *
- * Revision 1.13  2003/08/24 13:10:26  lukasz
- * - added few comments
- * - s/<?/<?php/g
- *
- * Revision 1.12  2003/08/24 00:59:29  lukasz
- * - LMSDB: GetAllByKey($query, $key, $inputarray)
- * - LMS: more fixes for new DAL
- *
- * Revision 1.11  2003/08/22 13:15:17  lukasz
- * - ListTables()
- *
- * Revision 1.10  2003/08/19 01:01:57  lukasz
- * - added Now() and Concat(), fixed Connect() (doesn't invoke _driver_selectdb(), because pgsql doesn't have _driver_selectdb())
- *
- * Revision 1.9  2003/08/18 16:47:37  lukasz
- * - once again fixed CVS tags
- *
- * Revision 1.8  2003/08/18 16:46:50  lukasz
- * - fixed CVS tags
- * - beta state - need testing
- *
- */
-
 ?>
