@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminadd.php,v 1.27 2004/03/03 08:23:45 lukasz Exp $
+ *  $Id: adminadd.php,v 1.28 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $adminadd = $_POST['adminadd'];
@@ -80,7 +80,6 @@ foreach($access['table'] as $idx => $row)
 }
 
 $layout['pagetitle'] = "Nowy administrator";
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('adminadd',$adminadd);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('accesslist',$accesslist);
