@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: admindel.php,v 1.16 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: admindel.php,v 1.17 2004/02/21 19:20:49 lukasz Exp $
  */
 
-if($_GET[is_sure]=="1")
+if($_GET['is_sure']=="1")
 {
-	$LMS->AdminDelete($_GET[id]);
+	$LMS->AdminDelete($_GET['id']);
 }
 
-header("Location: ?m=".$_SESSION[lastmodule]);
+header("Location: ?m=".$_SESSION['lastmodule']);
 
 ?>
\ No newline at end of file
