@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminedit.php,v 1.29 2004/03/03 09:11:14 alec Exp $
+ *  $Id: adminedit.php,v 1.30 2004/03/11 17:24:21 lukasz Exp $
  */
 
 if(!$LMS->AdminExists($_GET['id']))
@@ -93,12 +93,10 @@ foreach($access['table'] as $idx => $row)
 			$row['enabled']=TRUE;
 	$accesslist[] = $row;
 }
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('accesslist',$accesslist);
 $SMARTY->assign('admininfo',$admininfo);
 $SMARTY->assign('unlockedit',TRUE);
 $SMARTY->assign('error',$error);
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('admininfo.html');
 
 ?>
