@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.17 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: balancenew.php,v 1.18 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -30,7 +30,6 @@ $layout['pagetitle'] = "Nowa operacja finansowa";
 $SMARTY->assign('comment',$_SESSION['addbc']);
 $SMARTY->assign('time', $_SESSION['addbt']);
 $SMARTY->assign('value', $_SESSION['addbv']);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('users',$LMS->GetUserNames());
 $SMARTY->display('balancenew.html');
 
