@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.19 2003/08/27 19:25:32 lukasz Exp $
+ *  $Id: chooseip.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$p = $_GET[p];
+$p = $_GET['p'];
 
 if(!isset($p))
 	$js = "var targetfield = window.opener.targetfield;";
@@ -33,41 +33,26 @@ if($p == "main")
 
 $networks = $LMS->GetNetworks();
 
-if (isset($_POST[netid]))
-    $netid= $_POST[netid];
+if (isset($_POST['netid']))
+    $netid= $_POST['netid'];
 
-elseif (isset($_SESSION[netid]))
-    $netid = $_SESSION[netid];
+elseif (isset($_SESSION['netid']))
+    $netid = $_SESSION['netid'];
     
 else
-    $netid = $networks[0][id];
+    $netid = $networks[0]['id'];
 
-$_SESSION[netid] = $netid;
+$_SESSION['netid'] = $netid;
 
 if($p == "main")
 	$network = $LMS->GetNetwork($netid);
 
-$layout[pagetitle] = "Wybierz adres IP";
+$layout['pagetitle'] = "Wybierz adres IP";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("part",$p);
-$SMARTY->assign("js",$js);
-$SMARTY->assign("networks",$networks);
-$SMARTY->assign("network",$network);
+$SMARTY->assign('part',$p);
+$SMARTY->assign('js',$js);
+$SMARTY->assign('networks',$networks);
+$SMARTY->assign('network',$network);
+$SMARTY->display('chooseip.html');
 
-$SMARTY->display("chooseip.html");
-
-/*
- * $Log: chooseip.php,v $
- * Revision 1.19  2003/08/27 19:25:32  lukasz
- * - changed format of ipaddr storage in database
- *
- * Revision 1.18  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.17  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
