@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,13 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: choosemac.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: choosemac.php,v 1.15 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle] = "Wybierz adres MAC";
+$layout['pagetitle'] = "Wybierz adres MAC";
 
-$p = $_GET[p];
-$netid = $_POST[netid];
+$p = $_GET['p'];
+$netid = $_POST['netid'];
 
 if(!isset($p))
 	$js = "var targetfield = window.opener.targetfield;";
@@ -37,9 +37,9 @@ if($p == "main")
 if($p == "main")
 {
 	$maclist = $LMS->GetMACs();
-	if($LMS->CONFIG[phpui][arpd_servers])
+	if($LMS->CONFIG['phpui']['arpd_servers'])
 	{
-		$servers = split(' ',eregi_replace("[\t ]+"," ",$LMS->CONFIG[phpui][arpd_servers]));
+		$servers = split(' ',eregi_replace("[\t ]+"," ",$LMS->CONFIG['phpui']['arpd_servers']));
 		foreach($servers as $server)
 		{
 			list($addr,$port) = split(':',$server);
@@ -48,12 +48,11 @@ if($p == "main")
 			$maclist = array_merge($maclist,$LMS->GetRemoteMACs($addr,$port));
 		}
 	}
-	$SMARTY->assign("maclist",$maclist);
+	$SMARTY->assign('maclist',$maclist);
 }
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("part",$p);
-$SMARTY->assign("js",$js);
-$SMARTY->display("choosemac.html");
+$SMARTY->assign('part',$p);
+$SMARTY->assign('js',$js);
+$SMARTY->display('choosemac.html');
 
 ?>
