@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.11 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: invoicelist.php,v 1.12 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $layout['pagetitle'] = 'Lista faktur';
@@ -51,7 +51,6 @@ $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('start',$start);
 $SMARTY->assign('page',$page);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('marks',$marks);
 $SMARTY->assign('marked',$marked);
 $SMARTY->assign('invoicelist',$invoicelist);
