@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,15 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.6 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: invoicenew.php,v 1.8 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle] = 'Nowa faktura';
+$layout['pagetitle'] = 'Nowa faktura';
 $users = $LMS->GetUserNames();
 $tariffs = $LMS->GetTariffs();
-$contents = $_SESSION[invoicecontents];
-$customer = $_SESSION[invoicecustomer];
-$invoice = $_SESSION[invoice];
+$contents = $_SESSION['invoicecontents'];
+$customer = $_SESSION['invoicecustomer'];
+$invoice = $_SESSION['invoice'];
 $itemdata = r_trim($_POST);
 
 if($_GET['userid'] != '' && $LMS->UserExists($_GET['userid']))
@@ -71,8 +71,8 @@ switch($_GET['action'])
 	case 'setcustomer':
 		if($LMS->UserExists(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['userid'])))
 			$customer = $LMS->GetUser(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['userid']));
-		$invoice[paytime] = sprintf('%d', $_POST['invoice']['paytime']);
-		$invoice[paytype] = trim($_POST['invoice']['paytype']);
+		$invoice['paytime'] = sprintf('%d', $_POST['invoice']['paytime']);
+		$invoice['paytype'] = trim($_POST['invoice']['paytype']);
 	break;
 
 	case 'save':
@@ -80,9 +80,9 @@ switch($_GET['action'])
 		{
 			$iid = $LMS->AddInvoice(array('customer' => $customer, 'contents' => $contents, 'invoice' => $invoice));
 		}
-		unset($_SESSION[invoicecontents]);
-		unset($_SESSION[invoicecustomer]);
-		unset($_SESSION[invoice]);
+		unset($_SESSION['invoicecontents']);
+		unset($_SESSION['invoicecustomer']);
+		unset($_SESSION['invoice']);
 		header('Location: ?m=invoicelist&openonload='.$iid);
 		die;
 	break;
@@ -93,9 +93,9 @@ if($invoice['paytime'] < 1)
 if($invoice['paytype'] == '')
 	$invoice['paytype'] = 'GOTWKA';
 
-$_SESSION[invoice] = $invoice;
-$_SESSION[invoicecontents] = $contents;
-$_SESSION[invoicecustomer] = $customer;
+$_SESSION['invoice'] = $invoice;
+$_SESSION['invoicecontents'] = $contents;
+$_SESSION['invoicecustomer'] = $customer;
 
 if($_GET['action'] != '')
 {
@@ -109,7 +109,6 @@ $SMARTY->assign('customer',$customer);
 $SMARTY->assign('invoice',$invoice);
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->assign('users',$users);
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('invoicenew.html');
 
 ?>
