@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,12 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.20 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: mailing.php,v 1.23 2004/03/26 09:36:34 alec Exp $
  */
 
-$layout[pagetitle]="Mailing";
+$layout['pagetitle'] = "Mailing";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("mailing.html");
+$SMARTY->assign('networks', $LMS->GetNetworks());
+$SMARTY->display('mailing.html');
 
 ?>
