@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevdel.php,v 1.7 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdevdel.php,v 1.8 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
@@ -31,7 +31,6 @@ if(! $LMS->NetDevExists($_GET['id']))
 }		
 
 $layout['pagetitle'] = "Usunicie urzdzenia ID: ".sprintf("%04d",$_GET['id']);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('netdevid',$_GET['id']);
 
 if($LMS->CountNetDevLinks($_GET['id'])>0)
