@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevedit.php,v 1.24 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdevedit.php,v 1.26 2004/03/18 10:41:05 alec Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
@@ -127,9 +127,10 @@ case "formaddip":
 		$error['mac'] = "Podany MAC jest ju w bazie!";
 	elseif(!check_mac($nodeipdata['mac']))
 		$error['mac'] = "Podany adres MAC jest nieprawidowy!";
-
+	
 	if(!$error)
 	{
+		$nodeipdata['warning'] = '';
 		$LMS->NetDevLinkNode($LMS->NodeAdd($nodeipdata),$_GET['id']);
 		header("Location: ?m=netdevinfo&id=".$_GET['id']);
 		die;
@@ -248,7 +249,6 @@ $netdevips = $LMS->GetNetDevIPs($_GET['id']);
 
 $layout['pagetitle'] = "Edycja urzdzenia: ".$netdevdata['name']." ".$netdevdata['producer'];
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('netdevinfo',$netdevdata);
 $SMARTY->assign('netdevlist',$netdevconnected);
