@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.45 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: nodeedit.php,v 1.47 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
@@ -110,7 +110,9 @@ if(isset($nodeedit))
 
 	if($nodeedit['access']!=1)
 		$nodeedit['access'] = 0;
-	
+        if($nodeedit[warning]!=1)
+                $nodeedit[warning] = 0;	
+
 	if($nodeinfo['netdev'] != $nodeedit['netdev'] && $nodeedit['netdev'] != 0)
 	{
 		$netdev = $LMS->GetNetDev($nodeedit['netdev']); 
@@ -151,7 +153,6 @@ $SMARTY->assign('assignments',$assignments);
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('users',$users);
 $SMARTY->display('nodeedit.html');
