@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userinfo.php,v 1.32 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: userinfo.php,v 1.35 2004/03/14 20:28:44 lukasz Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -44,16 +44,19 @@ $tariffs = $LMS->GetTariffs();
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$layout['pagetitle']='Informacje o uytkowniku: '.$userinfo['username'];
+$layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'];
 
 $usernodes['ownerid'] = $_GET['id'];
-$SMARTY->assign('usernodes',$usernodes);
-$SMARTY->assign('balancelist',$balancelist);
-$SMARTY->assign('assignments',$assigments);
-$SMARTY->assign('error',$error);
-$SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
-$SMARTY->assign('tariffs',$tariffs);
+$SMARTY->assign(
+		array(
+			'usernodes' => $usernodes,
+			'balancelist' => $balancelist,
+			'assignments' => $assigments,
+			'error' => $error,
+			'userinfo' => $userinfo,
+			'tariffs' => $tariffs
+		     )
+		);
 $SMARTY->display('userinfo.html');
 
 ?>
