@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userlistdebt.php,v 1.17 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userlistdebt.php,v 1.19 2004/03/26 09:05:35 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -41,12 +41,19 @@ else
 	$s = $_GET['s'];
 $_SESSION['uls'] = $s;
 
+if(!isset($_GET['n']))
+	$n = $_SESSION['uln'];
+else
+	$n = $_GET['n'];
+$_SESSION['uln'] = $n;
+
 if (isset($_SESSION['ulp']) && !isset($_GET['page']))
 	$_GET['page'] = $_SESSION['ulp'];
 	    
 
-$userlist=$LMS->GetUserList($o,$s);
+$userlist=$LMS->GetUserList($o, $s, $n);
 $listdata['state'] = $userlist['state'];
+$listdata['network'] = $userlist['network'];
 $listdata['order'] = $userlist['order'];
 $listdata['direction'] = $userlist['direction'];
 
@@ -54,6 +61,7 @@ $_SESSION['ulp'] = $page;
 
 unset($userlist['total']);
 unset($userlist['state']);
+unset($userlist['network']);
 unset($userlist['order']);
 unset($userlist['below']);
 unset($userlist['over']);
@@ -78,9 +86,9 @@ $page = (! $_GET['page'] ? 1 : $_GET['page']);
 $pagelimit = (! $LMS->CONFIG['phpui']['userlist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['userlist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('userlist',$userlist);
 $SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('networks', $LMS->GetNetworks());
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('start',$start);
